@@ -23,7 +23,7 @@
 #define H_ADPLUG_FILEPROVIDER
 
 #include <string>
-#include <binio.h>
+#include <libbinio/binio.h>
 
 class CFileProvider
 {
